@@ -18,13 +18,12 @@ case $CONFIG_SHELL in *.exe) ;; *) CONFIG_SHELL=$CONFIG_SHELL.exe ;; esac
 export CONFIG_SHELL
 #
 conf_options="$target"
-conf_options="$target --prefix=/dev/env/DJDIR"
-conf_options="$target --disable-werror"
-conf_options="$conf_options --disable-libstdcxx-pch"
+conf_options="$conf_options --prefix=/dev/env/DJDIR"
+conf_options="$conf_options --disable-werror"
 conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++,ada"
+#conf_options="$conf_options --enable-languages=c,c++,fortran,objc,obj-c++"
 conf_options="$conf_options --enable-libquadmath-support"
 conf_options="$conf_options --enable-lto"
-#conf_options="$target --disable-nls"
 #
 srcdir=`(cd $src && pwd) | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
 builddir=`pwd | sed -e 's,^[a-zA-Z]:/,/,' -e 's,^/dev/[a-zA-Z]/,/,'`
